OC.L10N.register(
    "files",
    {
    "File could not be found" : "Datni nevar atrast",
    "Move or copy" : "Pārvietot vai kopēt",
    "Download" : "Lejupielādēt",
    "Delete" : "Dzēst",
    "Tags" : "Birkas",
    "Show list view" : "Rādīt saraksta skatu",
    "Show grid view" : "Rādīt režģa skatu",
    "Home" : "Mājas",
    "Close" : "Aizvērt",
    "Favorites" : "Iecienītie",
    "Could not create folder \"{dir}\"" : "Nevarēja izveidot mapi \"{dir}\"",
    "This will stop your current uploads." : "Tādējādi tiks pārtraukta jūsu pašreizējā augšupielāde.",
    "Upload cancelled." : "Augšupielāde ir atcelta.",
    "Processing files …" : "Notiek datņu apstrāde …",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Neizdodas augšupielādēt {filename}, jo tā ir vai nu mape vai 0 baitu saturoša datne.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nav pietiekami daudz brīvas vietas. Tiek augšupielādēti {size1}, bet pieejami tikai {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Mape \"{dir}\" vairs neeksistē",
    "Not enough free space" : "Nav pietiekami daudz brīvas vietas",
    "An unknown error has occurred" : "Radusies nezināma kļūda",
    "Uploading …" : "Augšupielādē…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} no {totalSize} ({bitrate})",
    "Actions" : "Darbības",
    "Rename" : "Pārsaukt",
    "Move" : "Pārvietot",
    "Copy" : "Kopēt",
    "Open" : "Atvērt",
    "Delete file" : "Dzēst datni",
    "Delete folder" : "Dzēst mapi",
    "Disconnect storage" : "Atvienot glabātuvi",
    "Could not load info for file \"{file}\"" : "Nevar ielādēt informāciju par datni \"{file}\"",
    "Files" : "Datnes",
    "Details" : "Detaļas",
    "Pending" : "Gaida savu kārtu",
    "Unable to determine date" : "Neizdevās noteikt datumu",
    "This operation is forbidden" : "Šī darbība ir aizliegta",
    "This directory is unavailable, please check the logs or contact the administrator" : "Šis direktorijs nav pieejams, lūdzu pārbaudiet žurnālus vai sazinieties ar administratoru",
    "Storage is temporarily not available" : "Glabātuve īslaicīgi nav pieejama",
    "Could not move \"{file}\", target exists" : "Nevarēja pārvietot \"{file}\", mērķis eksistē",
    "Could not move \"{file}\"" : "Nevarēja pārvietot \"{file}\"",
    "copy" : "kopēt",
    "{newName} already exists" : "{newName} jau eksistē",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nevarēja pārsaukt \"{fileName}\", tā vairs neeksistē",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nosaukums \"{targetName}\" jau tiek izmantots mapē \"{dir}\". Lūdzu izvēlies citu nosaukumu.",
    "Could not rename \"{fileName}\"" : "Nevarēja pārsaukt \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nevarēja izveidot datni \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nevarēja izveidot datni \"{file}\", jo tā jau eksistē",
    "Could not create folder \"{dir}\" because it already exists" : "Nevarēja izveidot mapi \"{dir}\", jo tā jau eksistē",
    "Error deleting file \"{fileName}\"." : "Kļūda dzēšot datni \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Nav nekas atrasts citā mapēs {tag}{filter}{endtag}",
    "Name" : "Nosaukums",
    "Size" : "Izmērs",
    "Modified" : "Mainīts",
    "_%n folder_::_%n folders_" : ["%n mapes","%n mape","%n mapes"],
    "_%n file_::_%n files_" : ["%n datnes","%n datne","%n datnes"],
    "{dirs} and {files}" : "{dirs} un {files}",
    "_including %n hidden_::_including %n hidden_" : ["ieskaitot %n paslēptos","ieskaitot %n paslēptos","ieskaitot %n paslēptos"],
    "_Uploading %n file_::_Uploading %n files_" : ["%n","Augšupielāde %n failu","Augšupielādē %n datnes"],
    "\"{name}\" is an invalid file name." : "\"{name}\" ir nepareizs datnes nosaukums.",
    "File name cannot be empty." : "Datnes nosaukums nevar būt tukšs.",
    "\"/\" is not allowed inside a file name." : "\"/\" nav atļauts faila nosaukumā.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" nav atļauts faila tips",
    "View in folder" : "Skatīt mapē",
    "Path" : "Ceļš",
    "_%n byte_::_%n bytes_" : ["%n baiti","%n baits","%n baiti"],
    "Favorited" : "Favorīti",
    "Favorite" : "Iecienītais",
    "New folder" : "Jauna mape",
    "Upload file" : "Augšupielādēt datni",
    "Recent" : "Nesenās",
    "Remove from favorites" : "Noņemt no favorītiem",
    "Add to favorites" : "Pievienot izlasei",
    "An error occurred while trying to update the tags" : "Notika kļūda mēģinot atjaunot birkas",
    "Added to favorites" : "Pievienot favorītiem",
    "Removed from favorites" : "Noņemt no favorītiem",
    "You added {file} to your favorites" : "Pievienoji {file} saviem favorītiem",
    "You removed {file} from your favorites" : "Noņēmi {file} no saviem favorītiem",
    "File changes" : "Datnes izmaiņas",
    "Created by {user}" : "Izveidoja {user}",
    "Changed by {user}" : "Izmainīja {user}",
    "Deleted by {user}" : "Dzēsa {user}",
    "Restored by {user}" : "Atjaunoja {user}",
    "Renamed by {user}" : "Pārdēvēja {user}",
    "Moved by {user}" : "Pārvietoja {user}",
    "\"remote user\"" : "\"attālināts lietotājs\"",
    "You created {file}" : "Jūs izveidojāt {file}",
    "{user} created {file}" : "{user} izveidoja {file}",
    "{file} was created in a public folder" : "{file} tika izveidots publiskajā mapē",
    "You changed {file}" : "Jūs izmainījāt {file}",
    "{user} changed {file}" : "{user} mainīts {file}",
    "You deleted {file}" : "Jūs izdzēsāt {file}",
    "{user} deleted {file}" : "{user} izdzēsa {file}",
    "You restored {file}" : "Tu atjaunoji {file}",
    "{user} restored {file}" : "{user} atjaunoja {file}",
    "You renamed {oldfile} to {newfile}" : "Pārdēvēji {oldfile} uz {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} pārdēvēja {oldfile} uz {newfile}",
    "You moved {oldfile} to {newfile}" : "Pārvietoji {oldfile} uz {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} pārvietoja {oldfile} uz {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Datne ir pievienota vai noņemta no jūsu <strong>favorītiem</strong>",
    "A file or folder has been <strong>changed</strong>" : "<strong>Izmainīta</strong> datne vai mape",
    "All files" : "Visas datnes",
    "Upload (max. %s)" : "Augšupielādēt (maks. %s)",
    "Accept" : "Akceptēt",
    "Reject" : "Noraidīt",
    "in %s" : "iekš %s",
    "Select all" : "Atzīmēt visu",
    "Change" : "Mainīt",
    "Unknown error" : "Nezināma kļūda",
    "No files in here" : "Šeit nav datņu",
    "Go back" : "Atpakaļ",
    "Files settings" : "Failu iestatījumi",
    "Show hidden files" : "Rādīt slēptās datnes",
    "Crop image previews" : "Apgriezt attēlu priekšskatījumus",
    "Additional settings" : "Papildu iestatījumi",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Kopēt starpliktuvē",
    "Use this address to access your Files via WebDAV" : "Izmantojiet šo adresi, lai piekļūtu savām datnēm, izmantojot WebDAV",
    "Cancel" : "Atcelt",
    "Create" : "Izveidot",
    "Delete permanently" : "Dzēst pavisam",
    "Toggle grid view" : "Pārslēgt režģa skatu",
    "Upload some content or sync with your devices!" : "Augšupielādē kaut ko vai sinhronizē saturu ar savām ierīcēm!",
    "No entries found in this folder" : "Šajā mapē nekas nav atrasts",
    "Upload too large" : "Datne ir par lielu, lai to augšupielādētu",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Augšupielādējamās datnes pārsniedz servera pieļaujamo datņu augšupielādes apjomu",
    "Files and folders you mark as favorite will show up here" : "Datnes un mapes, ko atzīmēsiet kā favorītus, tiks rādīti šeit",
    "Shares" : "Koplietots",
    "Shared with others" : "Koplietots ar citiem",
    "Shared with you" : "Koplietots ar tevi",
    "Shared by link" : "Koplietots ar saiti",
    "Deleted shares" : "Dzēstās koplietotnes",
    "Pending shares" : "Gaidošie koplietojumi",
    "Text file" : "Teksta datne",
    "New text file.txt" : "Jauna teksta datne.txt",
    "Storage invalid" : "Nepareiza glabātuve",
    "Select" : "Norādīt",
    "You don’t have permission to upload or create files here" : "Jums nav tiesību šeit augšupielādēt vai veidot datnes",
    "New" : "Jauna",
    "Copied!" : "Nokopēts!",
    "Unlimited" : "Neierobežota",
    "%s used" : "%s izmantoti",
    "%1$s of %2$s used" : "%1$s no %2$s lietoti",
    "Settings" : "Iestatījumi",
    "Deleted files" : "Dzēstās datnes"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
